@@ -125,10 +125,10 @@ class Algorithm(Generic[JobDetailsT, ResultT]):
 
         return self
 
-    def run(self, callable: Callable[[Self], ResultT]) -> Self:
+    def run(self, callable: Callable[[Self], ResultT], is_check_test=True) -> Self:
         self.logger.info("Running algorithm...")
         try:
-            if self._runtime == RuntimeMode.TEST:
+            if is_check_test and self._runtime == RuntimeMode.TEST:
                 callable = default_test_run
 
             self._result = callable(self)
@@ -140,12 +140,14 @@ class Algorithm(Generic[JobDetailsT, ResultT]):
     def save_results(
         self,
         callable: Callable[[ResultT, Path, Algorithm], None] = default_save,
+        *,
+        override_path: Path | None = None,
     ) -> None:
         self.logger.info("Saving results...")
         try:
             callable(
                 results=self.result,
-                base_path=self.job_details.paths.outputs,
+                base_path=override_path or self.job_details.paths.outputs,
                 algorithm=self,
             )
         except Exception as e:
